@@ -62,9 +62,6 @@ sub _get_peardir {
 
 sub _get_mainpackage {
 	my @packages = split("\n", _shell_exec('dh_listpackages'));
-	if (scalar(@packages) != 1) {
-		error("only one binary package supported, got ".scalar(@packages));
-	}
 	return $packages[0];
 }
 
